@@ -1,6 +1,7 @@
 import pytest
 
-from nypl_py_utils import RedshiftClient, RedshiftClientError
+from nypl_py_utils.classes.redshift_client import (
+    RedshiftClient, RedshiftClientError)
 
 
 class TestRedshiftClient:
@@ -19,7 +20,8 @@ class TestRedshiftClient:
         mock_redshift_conn.assert_called_once_with(host='test_host',
                                                    database='test_database',
                                                    user='test_user',
-                                                   password='test_password')
+                                                   password='test_password',
+                                                   sslmode='verify-full')
 
     def test_execute_query(self, mock_redshift_conn, test_instance, mocker):
         test_instance.connect()
@@ -60,6 +62,43 @@ class TestRedshiftClient:
         test_instance.conn.rollback.assert_called_once()
         mock_cursor.close.assert_called_once()
 
+    def test_execute_transaction(self, mock_redshift_conn, test_instance,
+                                 mocker):
+        test_instance.connect()
+
+        mock_cursor = mocker.MagicMock()
+        test_instance.conn.cursor.return_value = mock_cursor
+
+        test_instance.execute_transaction([('query 1', None),
+                                           ('query 2 %s %s', ('a', 1))])
+        mock_cursor.execute.assert_has_calls([
+            mocker.call('BEGIN TRANSACTION;'),
+            mocker.call('query 1', None),
+            mocker.call('query 2 %s %s', ('a', 1)),
+            mocker.call('END TRANSACTION;')])
+        test_instance.conn.commit.assert_called_once()
+        mock_cursor.close.assert_called_once()
+
+    def test_execute_transaction_with_exception(
+            self, mock_redshift_conn, test_instance, mocker):
+        test_instance.connect()
+
+        mock_cursor = mocker.MagicMock()
+        mock_cursor.execute.side_effect = [None, None, Exception()]
+        test_instance.conn.cursor.return_value = mock_cursor
+
+        with pytest.raises(RedshiftClientError):
+            test_instance.execute_transaction(
+                [('query 1', None), ('query 2', None)])
+
+        mock_cursor.execute.assert_has_calls([
+            mocker.call('BEGIN TRANSACTION;'),
+            mocker.call('query 1', None),
+            mocker.call('query 2', None)])
+        test_instance.conn.commit.assert_not_called()
+        test_instance.conn.rollback.assert_called_once()
+        mock_cursor.close.assert_called_once()
+
     def test_close_connection(self, mock_redshift_conn, test_instance):
         test_instance.connect()
         test_instance.close_connection()
